@@ -1,19 +1,7 @@
-/* This file is part of Step.
-   Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+/*.
+    SPDX-FileCopyrightText: 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
 
-   Step is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   Step is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with Step; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "worldbrowser.h"
@@ -33,7 +21,7 @@
 class WorldBrowserView: public QTreeView
 {
 public:
-    WorldBrowserView(QWidget* parent = 0);
+    WorldBrowserView(QWidget* parent = nullptr);
     void reset() override;
 
 protected:
@@ -100,7 +88,12 @@ void WorldBrowserView::drawBranches(QPainter *painter, const QRect &rect, const
 {
     // Inspired by qt-designer code in src/components/propertyeditor/qpropertyeditor.cpp
     if(!index.parent().isValid()) return;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QStyleOptionViewItem opt;
+    initViewItemOption(&opt);
+#else
     QStyleOptionViewItem opt = viewOptions();
+#endif
 
     if(model()->hasChildren(index)) {
         opt.state |= QStyle::State_Children;
